@@ -85,7 +85,7 @@ class DiscreteEnv(gym.Env):
     self.state = self.df   #self.df.sample(n=1, random_state=1).values.reshape(3,) 
     
     data = []
-    for row in self.df    #.itertuples(index=False):
+    for row in self.state.itertuples(index=False):    #self.df.itertuples(index=False):
       Xs = row[0]
       Xa = row[1]
       Y = row[2]
